@@ -51,11 +51,15 @@ struct gtk_mod {
 	GtkWidget *accounts_menu;
 	GtkWidget *history_menu;
 	GtkWidget *status_menu;
+	GtkWidget *menu_window;
+	GtkWidget *menu_button;
 	GSList *accounts_menu_group;
 	struct dial_dialog *dial_dialog;
 	GSList *call_windows;
 	GSList *incoming_call_menus;
 	bool clean_number;
+	bool use_status_icon;
+	bool use_window;
 	struct ua *ua_cur;
 	bool icon_call_missed;
 	bool icon_call_outgoing;
@@ -65,7 +69,6 @@ struct gtk_mod {
 static struct gtk_mod mod_obj;
 
 enum gtk_mod_events {
-	MQ_POPUP,
 	MQ_CONNECT,
 	MQ_CONNECTATTENDED,
 	MQ_QUIT,
@@ -116,7 +119,7 @@ static void menu_on_about(GtkMenuItem *menuItem, gpointer arg)
 
 	gtk_show_about_dialog(NULL,
 			"program-name", "baresip",
-			"version", BARESIP_VERSION,
+			      "version", baresip_version(),
 			"logo-icon-name", "call-start",
 			"copyright", COPYRIGHT,
 			"comments", COMMENTS,
@@ -312,7 +315,7 @@ static void menu_on_incoming_call_reject(GtkMenuItem *menuItem,
 
 
 static GtkMenuItem *accounts_menu_add_item(struct gtk_mod *mod,
-					   struct ua *ua)
+						struct ua *ua)
 {
 	GtkMenuShell *accounts_menu = GTK_MENU_SHELL(mod->accounts_menu);
 	GtkWidget *item;
@@ -387,21 +390,21 @@ static void update_ua_presence(struct gtk_mod *mod)
 }
 
 
-static const char *ua_event_reg_str(enum ua_event ev)
+static const char *ua_event_reg_str(enum bevent_ev ev)
 {
 	switch (ev) {
 
-	case UA_EVENT_REGISTERING:      return "registering";
-	case UA_EVENT_REGISTER_OK:      return "OK";
-	case UA_EVENT_REGISTER_FAIL:    return "ERR";
-	case UA_EVENT_UNREGISTERING:    return "unregistering";
+	case BEVENT_REGISTERING:      return "registering";
+	case BEVENT_REGISTER_OK:      return "OK";
+	case BEVENT_REGISTER_FAIL:    return "ERR";
+	case BEVENT_UNREGISTERING:    return "unregistering";
 	default: return "?";
 	}
 }
 
 
 static void accounts_menu_set_status(struct gtk_mod *mod,
-				     struct ua *ua, enum ua_event ev)
+					struct ua *ua, enum bevent_ev ev)
 {
 	GtkMenuItem *item = accounts_menu_get_item(mod, ua);
 	char buf[256];
@@ -517,7 +520,7 @@ static void denotify_incoming_call(struct gtk_mod *mod, struct call *call)
 			gtk_widget_destroy(menu_item);
 			mod->incoming_call_menus =
 				g_slist_delete_link(mod->incoming_call_menus,
-						    item);
+							item);
 		}
 	}
 }
@@ -538,7 +541,7 @@ static void answer_activated(GSimpleAction *action, GVariant *parameter,
 
 
 static void reject_activated(GSimpleAction *action, GVariant *parameter,
-			     gpointer arg)
+				gpointer arg)
 {
 	struct gtk_mod *mod = arg;
 	struct call *call = get_call_from_gvariant(parameter);
@@ -554,7 +557,7 @@ static void reject_activated(GSimpleAction *action, GVariant *parameter,
 
 
 static struct call_window *new_call_window(struct gtk_mod *mod,
-					   struct call *call)
+						struct call *call)
 {
 	struct call_window *win = call_window_new(call, mod, NULL);
 	if (call) {
@@ -565,8 +568,8 @@ static struct call_window *new_call_window(struct gtk_mod *mod,
 
 
 static struct call_window *new_call_transfer_window(struct gtk_mod *mod,
-					   struct call *call,
-					   struct call *attended_call)
+						struct call *call,
+						struct call *attended_call)
 {
 	struct call_window *win = call_window_new(call, mod, attended_call);
 	if (call) {
@@ -577,7 +580,7 @@ static struct call_window *new_call_transfer_window(struct gtk_mod *mod,
 
 
 static struct call_window *get_call_window(struct gtk_mod *mod,
-					   struct call *call)
+						struct call *call)
 {
 	GSList *wins;
 
@@ -611,36 +614,35 @@ void gtk_mod_call_window_closed(struct gtk_mod *mod, struct call_window *win)
 }
 
 
-static void ua_event_handler(struct ua *ua,
-			     enum ua_event ev,
-			     struct call *call,
-			     const char *prm,
-			     void *arg)
+static void event_handler(enum bevent_ev ev, struct bevent *event, void *arg)
 {
 	struct gtk_mod *mod = arg;
 	struct call_window *win;
+	struct ua   *ua   = bevent_get_ua(event);
+	struct call *call = bevent_get_call(event);
+	const char  *txt  = bevent_get_text(event);
 
 	gdk_threads_enter();
 
 	switch (ev) {
 
-	case UA_EVENT_REGISTERING:
-	case UA_EVENT_UNREGISTERING:
-	case UA_EVENT_REGISTER_OK:
-	case UA_EVENT_REGISTER_FAIL:
+	case BEVENT_REGISTERING:
+	case BEVENT_UNREGISTERING:
+	case BEVENT_REGISTER_OK:
+	case BEVENT_REGISTER_FAIL:
 		accounts_menu_set_status(mod, ua, ev);
 		break;
 
 #ifdef USE_NOTIFICATIONS
-	case UA_EVENT_CALL_INCOMING:
+	case BEVENT_CALL_INCOMING:
 		notify_incoming_call(mod, call);
 		break;
 #endif
 
-	case UA_EVENT_CALL_CLOSED:
+	case BEVENT_CALL_CLOSED:
 		win = get_call_window(mod, call);
 		if (win)
-			call_window_closed(win, prm);
+			call_window_closed(win, txt);
 		denotify_incoming_call(mod, call);
 		if (!call_is_outgoing(call)
 			&& call_state(call) != CALL_STATE_TERMINATED
@@ -649,36 +651,45 @@ static void ua_event_handler(struct ua *ua,
 				call_peeruri(call),
 				CALL_MISSED, call_peername(call));
 
-			gtk_status_icon_set_from_icon_name(
-				mod->status_icon,
-				(mod->icon_call_missed) ?
+			if (mod->use_status_icon)
+				gtk_status_icon_set_from_icon_name(
+					mod->status_icon,
+					(mod->icon_call_missed) ?
 					"call-missed-symbolic" : "call-stop");
+
+			if (mod->use_window)
+				gtk_button_set_image(
+					GTK_BUTTON(mod->menu_button),
+					gtk_image_new_from_icon_name(
+						(mod->icon_call_missed) ?
+					"call-missed-symbolic" : "call-stop",
+					GTK_ICON_SIZE_SMALL_TOOLBAR));
 		}
 		break;
 
-	case UA_EVENT_CALL_RINGING:
+	case BEVENT_CALL_RINGING:
 		win = get_create_call_window(mod, call);
 		if (win)
 			call_window_ringing(win);
 		break;
 
-	case UA_EVENT_CALL_PROGRESS:
+	case BEVENT_CALL_PROGRESS:
 		win = get_create_call_window(mod, call);
 		if (win)
 			call_window_progress(win);
 		break;
 
-	case UA_EVENT_CALL_ESTABLISHED:
+	case BEVENT_CALL_ESTABLISHED:
 		win = get_create_call_window(mod, call);
 		if (win)
 			call_window_established(win);
 		denotify_incoming_call(mod, call);
 		break;
 
-	case UA_EVENT_CALL_TRANSFER_FAILED:
+	case BEVENT_CALL_TRANSFER_FAILED:
 		win = get_create_call_window(mod, call);
 		if (win)
-			call_window_transfer_failed(win, prm);
+			call_window_transfer_failed(win, txt);
 		break;
 
 	default:
@@ -691,8 +702,8 @@ static void ua_event_handler(struct ua *ua,
 
 #ifdef USE_NOTIFICATIONS
 static void message_handler(struct ua *ua,
-			    const struct pl *peer, const struct pl *ctype,
-			    struct mbuf *body, void *arg)
+				const struct pl *peer, const struct pl *ctype,
+				struct mbuf *body, void *arg)
 {
 	struct gtk_mod *mod = arg;
 	char title[128];
@@ -735,9 +746,9 @@ static void message_handler(struct ua *ua,
 #endif
 
 
-static void popup_menu(struct gtk_mod *mod, GtkMenuPositionFunc position,
-		gpointer position_arg, guint button, guint32 activate_time)
+static void popup_menu(struct gtk_mod *mod, GdkEventButton *event)
 {
+	(void)event;
 	if (!mod->contacts_inited) {
 		init_contacts_menu(mod);
 		mod->contacts_inited = TRUE;
@@ -749,22 +760,30 @@ static void popup_menu(struct gtk_mod *mod, GtkMenuPositionFunc position,
 
 	gtk_widget_show_all(mod->app_menu);
 
-	gtk_menu_popup(GTK_MENU(mod->app_menu), NULL, NULL,
-			position, position_arg,
-			button, activate_time);
+	gtk_menu_popup_at_pointer(GTK_MENU(mod->app_menu), NULL);
 }
 
 
 static gboolean status_icon_on_button_press(GtkStatusIcon *status_icon,
-					    GdkEventButton *event,
-					    struct gtk_mod *mod)
+						GdkEventButton *event,
+						struct gtk_mod *mod)
 {
-	popup_menu(mod, gtk_status_icon_position_menu, status_icon,
-			event->button, event->time);
+	popup_menu(mod, event);
 	gtk_status_icon_set_from_icon_name(status_icon, "call-start");
 	return TRUE;
 }
 
+static gboolean menu_button_on_button_press(GtkWidget *button,
+						GdkEventButton *event,
+						struct gtk_mod *mod)
+{
+	popup_menu(mod, event);
+	gtk_button_set_image(GTK_BUTTON(button),
+		gtk_image_new_from_icon_name("call-start",
+		GTK_ICON_SIZE_SMALL_TOOLBAR));
+	return TRUE;
+}
+
 
 int gtk_mod_connect(struct gtk_mod *mod, const char *uri)
 {
@@ -859,12 +878,6 @@ static void mqueue_handler(int id, void *data, void *arg)
 
 	switch ((enum gtk_mod_events)id) {
 
-	case MQ_POPUP:
-		gdk_threads_enter();
-		popup_menu(mod, NULL, NULL, 0, GPOINTER_TO_UINT(data));
-		gdk_threads_leave();
-		break;
-
 	case MQ_CONNECT:
 		uri = data;
 		err = ua_connect(ua, &call, NULL, uri, VIDMODE_ON);
@@ -964,7 +977,7 @@ static int gtk_thread(void *arg)
 
 	g_set_application_name("baresip");
 	mod->app = g_application_new("com.github.baresip",
-				     G_APPLICATION_FLAGS_NONE);
+					G_APPLICATION_FLAGS_NONE);
 
 	g_application_register(G_APPLICATION (mod->app), NULL, &err);
 	if (err != NULL) {
@@ -978,19 +991,50 @@ static int gtk_thread(void *arg)
 	notify_init("baresip");
 #endif
 
-	mod->status_icon = gtk_status_icon_new_from_icon_name("call-start");
-	if (mod->status_icon == NULL) {
-		info("gtk_menu is not supported\n");
-		module_close();
-		return 1;
+	if (mod->use_window)
+	{
+		mod->menu_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+		gtk_window_set_title(
+			GTK_WINDOW(mod->menu_window), "BareSIP GTK");
+		gtk_window_set_default_size(
+			GTK_WINDOW(mod->menu_window), 350, 50);
+		gtk_window_set_default_icon_name(
+			"call-start");
+
+		mod->menu_button = gtk_button_new_from_icon_name(
+			"call-start", GTK_ICON_SIZE_BUTTON);
+		g_signal_connect(G_OBJECT(mod->menu_button),
+				"button_press_event",
+				G_CALLBACK(menu_button_on_button_press), mod);
+		gtk_container_add(
+			GTK_CONTAINER(mod->menu_window), mod->menu_button);
+
+		gtk_widget_show_all(mod->menu_window);
+		g_signal_connect(mod->menu_window, "destroy",
+					G_CALLBACK(menu_on_quit), mod);
 	}
 
-	gtk_status_icon_set_tooltip_text (mod->status_icon, "baresip");
+	if (mod->use_status_icon)
+	{
+		mod->status_icon = NULL;
+		mod->status_icon =
+			gtk_status_icon_new_from_icon_name("call-start");
 
-	g_signal_connect(G_OBJECT(mod->status_icon),
-			"button_press_event",
-			G_CALLBACK(status_icon_on_button_press), mod);
-	gtk_status_icon_set_visible(mod->status_icon, TRUE);
+		if (!gtk_status_icon_get_visible(mod->status_icon)) {
+			info("gtk status icon is not supported. ");
+			info("Disable gtk_use_status_icon in the settings\n");
+			module_close();
+			return 1;
+		}
+
+		gtk_status_icon_set_tooltip_text(
+			mod->status_icon, "baresip");
+
+		g_signal_connect(G_OBJECT(mod->status_icon),
+				"button_press_event",
+				G_CALLBACK(status_icon_on_button_press), mod);
+		gtk_status_icon_set_visible(mod->status_icon, TRUE);
+	}
 
 	mod->contacts_inited = false;
 	mod->dial_dialog = NULL;
@@ -1091,11 +1135,11 @@ static int gtk_thread(void *arg)
 
 	info("gtk_menu starting\n");
 
-	uag_event_register(ua_event_handler, mod);
+	bevent_register(event_handler, mod);
 	mod->run = true;
 	gtk_main();
 	mod->run = false;
-	uag_event_unregister(ua_event_handler);
+	bevent_unregister(event_handler);
 
 	mod->dial_dialog = mem_deref(mod->dial_dialog);
 
@@ -1135,8 +1179,9 @@ static int16_t calc_avg_s16(const int16_t *sampv, size_t sampc)
 
 
 static int vu_encode_update(struct aufilt_enc_st **stp, void **ctx,
-			    const struct aufilt *af, struct aufilt_prm *prm,
-			    const struct audio *au)
+				const struct aufilt *af,
+				struct aufilt_prm *prm,
+				const struct audio *au)
 {
 	struct vumeter_enc *st;
 	(void)ctx;
@@ -1169,9 +1214,11 @@ static int vu_encode_update(struct aufilt_enc_st **stp, void **ctx,
 }
 
 
-static int vu_decode_update(struct aufilt_dec_st **stp, void **ctx,
-			    const struct aufilt *af, struct aufilt_prm *prm,
-			    const struct audio *au)
+static int vu_decode_update(struct aufilt_dec_st **stp,
+				void **ctx,
+				const struct aufilt *af,
+				struct aufilt_prm *prm,
+				const struct audio *au)
 {
 	struct vumeter_dec *st;
 	(void)ctx;
@@ -1235,28 +1282,20 @@ static struct aufilt vumeter = {
 };
 
 
-static int cmd_popup_menu(struct re_printf *pf, void *unused)
-{
-	(void)pf;
-	(void)unused;
-
-	mqueue_push(mod_obj.mq, MQ_POPUP, GUINT_TO_POINTER(GDK_CURRENT_TIME));
-
-	return 0;
-}
-
-
-static const struct cmd cmdv[] = {
-	{"gtk", 0,   0, "Pop up GTK+ menu",         cmd_popup_menu       },
-};
-
-
 static int module_init(void)
 {
 	int err;
 
 	mod_obj.clean_number = false;
-	conf_get_bool(conf_cur(), "gtk_clean_number", &mod_obj.clean_number);
+	mod_obj.use_status_icon = false;
+	mod_obj.use_window = true;
+
+	conf_get_bool(conf_cur(),
+		"gtk_clean_number", &mod_obj.clean_number);
+	conf_get_bool(conf_cur(),
+		"gtk_use_status_icon", &mod_obj.use_status_icon);
+	conf_get_bool(conf_cur(),
+		"gtk_use_window", &mod_obj.use_window);
 
 	err = mqueue_alloc(&mod_obj.mq, mqueue_handler, &mod_obj);
 	if (err)
@@ -1266,20 +1305,16 @@ static int module_init(void)
 
 #ifdef USE_NOTIFICATIONS
 	err = message_listen(baresip_message(),
-			     message_handler, &mod_obj);
+				message_handler, &mod_obj);
 	if (err) {
 		warning("gtk: message_init failed (%m)\n", err);
 		return err;
 	}
 #endif
 
-	err = cmd_register(baresip_commands(), cmdv, RE_ARRAY_SIZE(cmdv));
-	if (err)
-		return err;
-
 	/* start the thread last */
 	err = thread_create_name(&mod_obj.thread, "gtk", gtk_thread,
-			     &mod_obj);
+				&mod_obj);
 	if (err)
 		return err;
 
@@ -1289,7 +1324,6 @@ static int module_init(void)
 
 static int module_close(void)
 {
-	cmd_unregister(baresip_commands(), cmdv);
 	if (mod_obj.run) {
 		gdk_threads_enter();
 		gtk_main_quit();
@@ -1310,7 +1344,7 @@ static int module_close(void)
 	g_slist_free(mod_obj.call_windows);
 	g_slist_free(mod_obj.incoming_call_menus);
 
-	uag_event_unregister(ua_event_handler);
+	bevent_unregister(event_handler);
 
 	return 0;
 }
