@@ -639,7 +639,9 @@ static int stream_pt_handler(uint8_t pt, struct mbuf *mb, void *arg)
  */
 static void stream_recv_handler(const struct rtp_header *hdr,
 				struct rtpext *extv, size_t extc,
-				struct mbuf *mb, unsigned lostc, bool *ignore,
+				struct mbuf *mb, unsigned lostc,
+				bool new_source,
+				bool *ignore,
 				void *arg)
 {
 	struct audio *a = arg;
@@ -649,6 +651,9 @@ static void stream_recv_handler(const struct rtp_header *hdr,
 	if (!a->aur)
 		return;
 
+	if (new_source)
+		aurecv_reset(a->aur);
+
 	aurecv_receive(a->aur, hdr, extv, extc, mb, lostc, ignore);
 }
 
@@ -775,18 +780,6 @@ int audio_alloc(struct audio **ap, struct list *streaml,
 	if (err)
 		goto out;
 
-	if (cfg->audio.level && offerer) {
-
-		a->extmap_aulevel = stream_generate_extmap_id(a->strm);
-		aurecv_set_extmap(a->aur, a->extmap_aulevel);
-
-		err = sdp_media_set_lattr(stream_sdpmedia(a->strm), true,
-					  "extmap",
-					  "%u %s",
-					  a->extmap_aulevel, uri_aulevel);
-		if (err)
-			goto out;
-	}
 
 	tx->mb = mbuf_alloc(STREAM_PRESZ + 4096);
 	tx->sampv = mem_zalloc(AUDIO_SAMPSZ * aufmt_sample_size(tx->enc_fmt),
@@ -862,6 +855,21 @@ int audio_alloc(struct audio **ap, struct list *streaml,
 }
 
 
+int audio_enable_level(struct audio *au)
+{
+	if (!au)
+		return EINVAL;
+
+	au->extmap_aulevel = stream_generate_extmap_id(au->strm);
+	aurecv_set_extmap(au->aur, au->extmap_aulevel);
+
+	return sdp_media_set_lattr(stream_sdpmedia(au->strm), false,
+				   "extmap",
+				   "%u %s",
+				   au->extmap_aulevel, uri_aulevel);
+}
+
+
 static int tx_thread(void *arg)
 {
 	struct audio *a = arg;
