@@ -887,12 +887,15 @@ static int stream_pt_handler(uint8_t pt, struct mbuf *mb, void *arg)
 /* Handle incoming stream data from the network */
 static void stream_recv_handler(const struct rtp_header *hdr,
 				struct rtpext *extv, size_t extc,
-				struct mbuf *mb, unsigned lostc, bool *ignore,
+				struct mbuf *mb, unsigned lostc,
+				bool new_source,
+				bool *ignore,
 				void *arg)
 {
 	struct video *v = arg;
 	(void)extv;
 	(void)extc;
+	(void)new_source;
 	(void)ignore;
 
 	MAGIC_CHECK(v);
@@ -1584,9 +1587,20 @@ int video_encoder_set(struct video *v, struct vidcodec *vc,
 
 	vtx = &v->vtx;
 
-	if (!vc->encupdh) {
+	if (!vc->encupdh || !vc->ench) {
 		info("video: vidcodec '%s' has no encoder\n", vc->name);
-		return ENOENT;
+
+		struct list *vidcodecl = vc->le.list;
+
+		struct vidcodec *vcd = (struct vidcodec *)
+			vidcodec_find_encoder(vidcodecl, vc->name);
+		if (!vcd) {
+			warning("video: could not find encoder (%s)\n",
+				vc->name);
+			return ENOENT;
+		}
+
+		vc = vcd;
 	}
 
 	mtx_lock(vtx->lock_enc);
@@ -1633,14 +1647,13 @@ int video_decoder_set(struct video *v, struct vidcodec *vc, int pt_rx,
 		return EINVAL;
 
 	/* handle vidcodecs without a decoder */
-	if (!vc->decupdh) {
+	if (!vc->decupdh || !vc->dech) {
 		struct list *vidcodecl = vc->le.list;
-		struct vidcodec *vcd;
 
 		info("video: vidcodec '%s' has no decoder\n", vc->name);
 
-		vcd = (struct vidcodec *)vidcodec_find_decoder(vidcodecl,
-							       vc->name);
+		struct vidcodec *vcd = (struct vidcodec *)
+			vidcodec_find_decoder(vidcodecl, vc->name);
 		if (!vcd) {
 			warning("video: could not find decoder (%s)\n",
 				vc->name);
